@@ -2,7 +2,7 @@
 #include <Python.h>
 #include <stdlib.h>
 #include <string.h>
-#include <llistobject.h>
+#include <listobject.c>
 
 int Get_minrun(char path[], int size_of_array)
 {
@@ -35,17 +35,19 @@ timsort(PyObject *self, PyObject *args)
     Py_ssize_t minrun;
     if (!PyArg_ParseTuple(args, "nO", &minrun, &arr))
         return NULL;
-    lPyList_Sort(arr, minrun);
+    PyList_Custom_Sort(arr, minrun);
     return PyLong_FromLong(1);
 }
 
 static PyMethodDef TimSortMethods[] = {
     {"timsort",  timsort, METH_VARARGS,
      "Execute a shell command."},
+    {"Get_minrun",  Get_minrun, METH_VARARGS,
+     "Execute a shell command."},
     {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
-static struct PyModuleDef timsortmodule = {
+static struct PyModuleDef timsort_module = {
     PyModuleDef_HEAD_INIT,
     "timsort",   /* name of module */
     NULL, /* module documentation, may be NULL */
@@ -57,6 +59,6 @@ static struct PyModuleDef timsortmodule = {
 PyMODINIT_FUNC
 PyInit_timsort(void)
 {
-    return PyModule_Create(&timsortmodule);
+    return PyModule_Create(&timsort_module);
 }
 
